@@ -403,7 +403,7 @@ class SSHKey:  # pylint:disable=too-many-instance-attributes
         try:
             parsed_url = urlparse(application)
         except ValueError as err:
-            raise InvalidKeyError(f"Application string: {err}") from err
+            raise InvalidKeyError("Application string: %s" % err) from err
         if parsed_url.scheme != b"ssh":
             raise InvalidKeyError('Application string must begin with "ssh:"')
 
